@@ -38,7 +38,9 @@ void MatrixRowCol::Add(const MatrixRowCol& mrc)
    // THIS += mrc
    REPORT
    int f = mrc.skip; int l = f + mrc.storage; int lx = skip + storage;
-   if (f < skip) f = skip; if (l > lx) l = lx; l -= f;
+   if (f < skip) f = skip; 
+   if (l > lx) l = lx; 
+   l -= f;
    if (l<=0) return;
    Real* elx=data+(f-skip); Real* el=mrc.data+(f-mrc.skip);
    while (l--) *elx++ += *el++;
@@ -49,7 +51,9 @@ void MatrixRowCol::AddScaled(const MatrixRowCol& mrc, Real x)
    REPORT
    // THIS += (mrc * x)
    int f = mrc.skip; int l = f + mrc.storage; int lx = skip + storage;
-   if (f < skip) f = skip; if (l > lx) l = lx; l -= f;
+   if (f < skip) f = skip; 
+   if (l > lx) l = lx; 
+   l -= f;
    if (l<=0) return;
    Real* elx=data+(f-skip); Real* el=mrc.data+(f-mrc.skip);
    while (l--) *elx++ += *el++ * x;
@@ -60,7 +64,9 @@ void MatrixRowCol::Sub(const MatrixRowCol& mrc)
    REPORT
    // THIS -= mrc
    int f = mrc.skip; int l = f + mrc.storage; int lx = skip + storage;
-   if (f < skip) f = skip; if (l > lx) l = lx; l -= f;
+   if (f < skip) f = skip; 
+   if (l > lx) l = lx; 
+   l -= f;
    if (l<=0) return;
    Real* elx=data+(f-skip); Real* el=mrc.data+(f-mrc.skip);
    while (l--) *elx++ -= *el++;
@@ -71,7 +77,9 @@ void MatrixRowCol::Inject(const MatrixRowCol& mrc)
 {
    REPORT
    int f = mrc.skip; int l = f + mrc.storage; int lx = skip + storage;
-   if (f < skip) f = skip; if (l > lx) l = lx; l -= f;
+   if (f < skip) f = skip; 
+   if (l > lx) l = lx; 
+   l -= f;
    if (l<=0) return;
    Real* elx=data+(f-skip); Real* ely=mrc.data+(f-mrc.skip);
    while (l--) *elx++ = *ely++;
@@ -82,7 +90,9 @@ Real DotProd(const MatrixRowCol& mrc1, const MatrixRowCol& mrc2)
    REPORT                                         // not accessed
    int f = mrc1.skip; int f2 = mrc2.skip;
    int l = f + mrc1.storage; int l2 = f2 + mrc2.storage;
-   if (f < f2) f = f2; if (l > l2) l = l2; l -= f;
+   if (f < f2) f = f2; 
+   if (l > l2) l = l2; 
+   l -= f;
    if (l<=0) return 0.0;
 
    Real* el1=mrc1.data+(f-mrc1.skip); Real* el2=mrc2.data+(f-mrc2.skip);
@@ -96,9 +106,11 @@ void MatrixRowCol::Add(const MatrixRowCol& mrc1, const MatrixRowCol& mrc2)
    // THIS = mrc1 + mrc2
    int f = skip; int l = skip + storage;
    int f1 = mrc1.skip; int l1 = f1 + mrc1.storage;
-   if (f1<f) f1=f; if (l1>l) l1=l;
+   if (f1<f) f1=f; 
+   if (l1>l) l1=l;
    int f2 = mrc2.skip; int l2 = f2 + mrc2.storage;
-   if (f2<f) f2=f; if (l2>l) l2=l;
+   if (f2<f) f2=f; 
+   if (l2>l) l2=l;
    Real* el = data + (f-skip);
    Real* el1 = mrc1.data+(f1-mrc1.skip); Real* el2 = mrc2.data+(f2-mrc2.skip);
    if (f1<f2)
@@ -168,9 +180,11 @@ void MatrixRowCol::Sub(const MatrixRowCol& mrc1, const MatrixRowCol& mrc2)
    // THIS = mrc1 - mrc2
    int f = skip; int l = skip + storage;
    int f1 = mrc1.skip; int l1 = f1 + mrc1.storage;
-   if (f1<f) f1=f; if (l1>l) l1=l;
+   if (f1<f) f1=f; 
+   if (l1>l) l1=l;
    int f2 = mrc2.skip; int l2 = f2 + mrc2.storage;
-   if (f2<f) f2=f; if (l2>l) l2=l;
+   if (f2<f) f2=f; 
+   if (l2>l) l2=l;
    Real* el = data + (f-skip);
    Real* el1 = mrc1.data+(f1-mrc1.skip); Real* el2 = mrc2.data+(f2-mrc2.skip);
    if (f1<f2)
@@ -332,11 +346,14 @@ void MatrixRowCol::Multiply(const MatrixRowCol& mrc1, const MatrixRowCol& mrc2)
 {
    int f = skip; int l = skip + storage;
    int f1 = mrc1.skip; int l1 = f1 + mrc1.storage;
-   if (f1<f) f1=f; if (l1>l) l1=l;
+   if (f1<f) f1=f; 
+   if (l1>l) l1=l;
    int f2 = mrc2.skip; int l2 = f2 + mrc2.storage;
-   if (f2<f) f2=f; if (l2>l) l2=l;
+   if (f2<f) f2=f; 
+   if (l2>l) l2=l;
    Real* el = data + (f-skip); int i;
-   if (f1<f2) f1 = f2; if (l1>l2) l1 = l2;
+   if (f1<f2) f1 = f2; 
+   if (l1>l2) l1 = l2;
    if (l1<=f1) { REPORT i = l-f; while (i--) *el++ = 0.0; }  // disjoint
    else
    {
