@@ -38,6 +38,7 @@ namespace realea {
 class ConfigException: public runtime_error {
 private:
 	string m_name;
+	string m_msg;
 
 public:
 	ConfigException(string name) : runtime_error(name) {
@@ -47,9 +48,9 @@ public:
 public:
 	virtual ~ConfigException(void) throw () { }
 	virtual const char *what(void) {
-		string msg;
-		msg = "Parameter Config " +m_name +" is not yet defined";
-		return msg.c_str();
+		
+		m_msg = "Parameter Config " +m_name +" is not yet defined";
+		return m_msg.c_str();
 	}
 };
 
