@@ -250,7 +250,7 @@ unsigned SWNDim::apply(ILSParameters *params, tChromosomeReal &sol, tFitness &so
 
 	 // Adapto bias 
 	 transform(p->bias.begin(), p->bias.end(), dif.begin(), p->bias.begin(), 
-		     ptr_fun(increm_bias));
+		     increm_bias);
 	 p->numSuccess++;
 	 p->numFailed = 0;
       }
@@ -270,7 +270,7 @@ unsigned SWNDim::apply(ILSParameters *params, tChromosomeReal &sol, tFitness &so
 
 	    // Disminuyo bias
 	    transform(p->bias.begin(), p->bias.end(), dif.begin(), p->bias.begin(), 
-			ptr_fun(dec_bias));
+			dec_bias);
 
 	    p->numSuccess++;
 	    p->numFailed = 0;
@@ -278,7 +278,7 @@ unsigned SWNDim::apply(ILSParameters *params, tChromosomeReal &sol, tFitness &so
 	 else {
 	    // Se reduce bias a la mitad
 	    transform(p->bias.begin(), p->bias.end(), dif.begin(), p->bias.begin(), 
-			ptr_fun(divide_bias));
+			divide_bias);
 	    p->numFailed++;
 	    p->numSuccess = 0;
 	 }
